OptionNumber

Enum OptionNumber 

pub enum OptionNumber {
    RegionCode,
    TraceRoute,
    SourceRoute,
    OperatorCallsign,
    MinRssi,
    RouteRetry,
    StationCallsign,
    MinSnr,
    Unknown(u16),
}
Known packet-option numbers.

Variants



RegionCode



TraceRoute



SourceRoute



OperatorCallsign



MinRssi



RouteRetry



StationCallsign



MinSnr



Unknown(u16)

Implementations

Source

impl OptionNumber

pub fn as_u16(self) -> u16

Return the numeric option number used on the wire.

pub fn is_critical(self) -> bool

Return whether the option is critical when unknown.

pub fn is_dynamic(self) -> bool

Return whether the option is considered dynamic for AAD purposes.