pub struct Scf(pub u8);Expand description
Security-control field wrapper.
Tuple Fields
0: u8Implementations
Sourceimpl Scf
impl Scf
Sourcepub const fn new(encrypted: bool, mic_size: MicSize, salt_present: bool) -> Self
pub const fn new(encrypted: bool, mic_size: MicSize, salt_present: bool) -> Self
Build an SCF from structured flags.
Sourcepub fn mic_size(self) -> Result<MicSize, ParseError>
pub fn mic_size(self) -> Result<MicSize, ParseError>
Decode the configured MIC size.
Sourcepub const fn salt_present(self) -> bool
pub const fn salt_present(self) -> bool
Return whether a salt field follows the frame counter.
Sourcepub const fn reserved_valid(self) -> bool
pub const fn reserved_valid(self) -> bool
Return whether the reserved low nibble is valid for the current spec.